Class: WebSocket::Frame::Handler::Base
- Inherits:
-
Object
- Object
- WebSocket::Frame::Handler::Base
- Defined in:
- lib/websocket/frame/handler/base.rb
Instance Method Summary collapse
-
#decode_frame ⇒ WebSocket::Frame::Incoming
Convert raw data to decoded frame.
-
#encode_frame ⇒ String
Convert data to raw frame ready to send to client.
-
#initialize(frame) ⇒ Base
constructor
A new instance of Base.
Constructor Details
#initialize(frame) ⇒ Base
Returns a new instance of Base.
6 7 8 |
# File 'lib/websocket/frame/handler/base.rb', line 6 def initialize(frame) @frame = frame end |
Instance Method Details
#decode_frame ⇒ WebSocket::Frame::Incoming
Convert raw data to decoded frame
18 19 20 |
# File 'lib/websocket/frame/handler/base.rb', line 18 def decode_frame raise NotImplementedError end |
#encode_frame ⇒ String
Convert data to raw frame ready to send to client
12 13 14 |
# File 'lib/websocket/frame/handler/base.rb', line 12 def encode_frame raise NotImplementedError end |